mock

package
v0.0.0-...-68a1676 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 2, 2024 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package mock is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCMDID

type MockCMDID struct {
	// contains filtered or unexported fields
}

MockCMDID is a mock of CMDID interface.

func NewMockCMDID

func NewMockCMDID(ctrl *gomock.Controller) *MockCMDID

NewMockCMDID creates a new mock instance.

func (*MockCMDID) AddDidDocument

func (m *MockCMDID) AddDidDocument(didDocument string) error

AddDidDocument mocks base method.

func (*MockCMDID) DidMethod

func (m *MockCMDID) DidMethod() string

DidMethod mocks base method.

func (*MockCMDID) EXPECT

func (m *MockCMDID) EXPECT() *MockCMDIDMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCMDID) EmitRevokeVcEvent

func (m *MockCMDID) EmitRevokeVcEvent(vcID string)

EmitRevokeVcEvent mocks base method.

func (*MockCMDID) EmitSetDidDocumentEvent

func (m *MockCMDID) EmitSetDidDocumentEvent(did, didDocument string)

EmitSetDidDocumentEvent mocks base method.

func (*MockCMDID) GetDidByAddress

func (m *MockCMDID) GetDidByAddress(address string) (string, error)

GetDidByAddress mocks base method.

func (*MockCMDID) GetDidByPubkey

func (m *MockCMDID) GetDidByPubkey(pk string) (string, error)

GetDidByPubkey mocks base method.

func (*MockCMDID) GetDidDocument

func (m *MockCMDID) GetDidDocument(did string) (string, error)

GetDidDocument mocks base method.

func (*MockCMDID) GetRevokedVcList

func (m *MockCMDID) GetRevokedVcList(vcIDSearch string, start, count int) ([]string, error)

GetRevokedVcList mocks base method.

func (*MockCMDID) IsValidDid

func (m *MockCMDID) IsValidDid(did string) (bool, error)

IsValidDid mocks base method.

func (*MockCMDID) RevokeVc

func (m *MockCMDID) RevokeVc(vcID string) error

RevokeVc mocks base method.

func (*MockCMDID) VerifyVc

func (m *MockCMDID) VerifyVc(vcJson string) (bool, error)

VerifyVc mocks base method.

func (*MockCMDID) VerifyVp

func (m *MockCMDID) VerifyVp(vpJson string) (bool, error)

VerifyVp mocks base method.

type MockCMDIDMockRecorder

type MockCMDIDMockRecorder struct {
	// contains filtered or unexported fields
}

MockCMDIDMockRecorder is the mock recorder for MockCMDID.

func (*MockCMDIDMockRecorder) AddDidDocument

func (mr *MockCMDIDMockRecorder) AddDidDocument(didDocument interface{}) *gomock.Call

AddDidDocument indicates an expected call of AddDidDocument.

func (*MockCMDIDMockRecorder) DidMethod

func (mr *MockCMDIDMockRecorder) DidMethod() *gomock.Call

DidMethod indicates an expected call of DidMethod.

func (*MockCMDIDMockRecorder) EmitRevokeVcEvent

func (mr *MockCMDIDMockRecorder) EmitRevokeVcEvent(vcID interface{}) *gomock.Call

EmitRevokeVcEvent indicates an expected call of EmitRevokeVcEvent.

func (*MockCMDIDMockRecorder) EmitSetDidDocumentEvent

func (mr *MockCMDIDMockRecorder) EmitSetDidDocumentEvent(did, didDocument interface{}) *gomock.Call

EmitSetDidDocumentEvent indicates an expected call of EmitSetDidDocumentEvent.

func (*MockCMDIDMockRecorder) GetDidByAddress

func (mr *MockCMDIDMockRecorder) GetDidByAddress(address interface{}) *gomock.Call

GetDidByAddress indicates an expected call of GetDidByAddress.

func (*MockCMDIDMockRecorder) GetDidByPubkey

func (mr *MockCMDIDMockRecorder) GetDidByPubkey(pk interface{}) *gomock.Call

GetDidByPubkey indicates an expected call of GetDidByPubkey.

func (*MockCMDIDMockRecorder) GetDidDocument

func (mr *MockCMDIDMockRecorder) GetDidDocument(did interface{}) *gomock.Call

GetDidDocument indicates an expected call of GetDidDocument.

func (*MockCMDIDMockRecorder) GetRevokedVcList

func (mr *MockCMDIDMockRecorder) GetRevokedVcList(vcIDSearch, start, count interface{}) *gomock.Call

GetRevokedVcList indicates an expected call of GetRevokedVcList.

func (*MockCMDIDMockRecorder) IsValidDid

func (mr *MockCMDIDMockRecorder) IsValidDid(did interface{}) *gomock.Call

IsValidDid indicates an expected call of IsValidDid.

func (*MockCMDIDMockRecorder) RevokeVc

func (mr *MockCMDIDMockRecorder) RevokeVc(vcID interface{}) *gomock.Call

RevokeVc indicates an expected call of RevokeVc.

func (*MockCMDIDMockRecorder) VerifyVc

func (mr *MockCMDIDMockRecorder) VerifyVc(vcJson interface{}) *gomock.Call

VerifyVc indicates an expected call of VerifyVc.

func (*MockCMDIDMockRecorder) VerifyVp

func (mr *MockCMDIDMockRecorder) VerifyVp(vpJson interface{}) *gomock.Call

VerifyVp indicates an expected call of VerifyVp.

type MockCMDIDOption

type MockCMDIDOption struct {
	// contains filtered or unexported fields
}

MockCMDIDOption is a mock of CMDIDOption interface.

func NewMockCMDIDOption

func NewMockCMDIDOption(ctrl *gomock.Controller) *MockCMDIDOption

NewMockCMDIDOption creates a new mock instance.

func (*MockCMDIDOption) AddBlackList

func (m *MockCMDIDOption) AddBlackList(dids []string) error

AddBlackList mocks base method.

func (*MockCMDIDOption) AddTrustIssuer

func (m *MockCMDIDOption) AddTrustIssuer(dids []string) error

AddTrustIssuer mocks base method.

func (*MockCMDIDOption) Delegate

func (m *MockCMDIDOption) Delegate(delegateeDid, resource, action string, expiration int64) error

Delegate mocks base method.

func (*MockCMDIDOption) DeleteBlackList

func (m *MockCMDIDOption) DeleteBlackList(dids []string) error

DeleteBlackList mocks base method.

func (*MockCMDIDOption) DeleteTrustIssuer

func (m *MockCMDIDOption) DeleteTrustIssuer(dids []string) error

DeleteTrustIssuer mocks base method.

func (*MockCMDIDOption) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockCMDIDOption) EmitAddBlackListEvent

func (m *MockCMDIDOption) EmitAddBlackListEvent(dids []string)

EmitAddBlackListEvent mocks base method.

func (*MockCMDIDOption) EmitAddTrustIssuerEvent

func (m *MockCMDIDOption) EmitAddTrustIssuerEvent(dids []string)

EmitAddTrustIssuerEvent mocks base method.

func (*MockCMDIDOption) EmitDelegateEvent

func (m *MockCMDIDOption) EmitDelegateEvent(delegatorDid, delegateeDid, resource, action string, start, expiration int64)

EmitDelegateEvent mocks base method.

func (*MockCMDIDOption) EmitDeleteBlackListEvent

func (m *MockCMDIDOption) EmitDeleteBlackListEvent(dids []string)

EmitDeleteBlackListEvent mocks base method.

func (*MockCMDIDOption) EmitDeleteTrustIssuerEvent

func (m *MockCMDIDOption) EmitDeleteTrustIssuerEvent(dids []string)

EmitDeleteTrustIssuerEvent mocks base method.

func (*MockCMDIDOption) EmitRevokeDelegateEvent

func (m *MockCMDIDOption) EmitRevokeDelegateEvent(delegatorDid, delegateeDid, resource, action string)

EmitRevokeDelegateEvent mocks base method.

func (*MockCMDIDOption) EmitSetTrustRootListEvent

func (m *MockCMDIDOption) EmitSetTrustRootListEvent(dids []string)

EmitSetTrustRootListEvent mocks base method.

func (*MockCMDIDOption) EmitSetVcTemplateEvent

func (m *MockCMDIDOption) EmitSetVcTemplateEvent(templateID, templateName, version, vcTemplate string)

EmitSetVcTemplateEvent mocks base method.

func (*MockCMDIDOption) EmitVcIssueLogEvent

func (m *MockCMDIDOption) EmitVcIssueLogEvent(issuer, did, templateID, vcID string)

EmitVcIssueLogEvent mocks base method.

func (*MockCMDIDOption) GetBlackList

func (m *MockCMDIDOption) GetBlackList(didSearch string, start, count int) ([]string, error)

GetBlackList mocks base method.

func (*MockCMDIDOption) GetDelegateList

func (m *MockCMDIDOption) GetDelegateList(delegatorDid, delegateeDid, resource, action string, start, count int) ([]*contract.DelegateInfo, error)

GetDelegateList mocks base method.

func (*MockCMDIDOption) GetTrustIssuer

func (m *MockCMDIDOption) GetTrustIssuer(didSearch string, start, count int) ([]string, error)

GetTrustIssuer mocks base method.

func (*MockCMDIDOption) GetTrustRootList

func (m *MockCMDIDOption) GetTrustRootList() ([]string, error)

GetTrustRootList mocks base method.

func (*MockCMDIDOption) GetVcIssueLogs

func (m *MockCMDIDOption) GetVcIssueLogs(issuer, did, templateID string, start, count int) ([]*contract.VcIssueLog, error)

GetVcIssueLogs mocks base method.

func (*MockCMDIDOption) GetVcIssuers

func (m *MockCMDIDOption) GetVcIssuers(did string) ([]string, error)

GetVcIssuers mocks base method.

func (*MockCMDIDOption) GetVcTemplate

func (m *MockCMDIDOption) GetVcTemplate(id, version string) (*contract.VcTemplate, error)

GetVcTemplate mocks base method.

func (*MockCMDIDOption) GetVcTemplateList

func (m *MockCMDIDOption) GetVcTemplateList(nameSearch string, start, count int) ([]*contract.VcTemplate, error)

GetVcTemplateList mocks base method.

func (*MockCMDIDOption) RevokeDelegate

func (m *MockCMDIDOption) RevokeDelegate(delegateeDid, resource, action string) error

RevokeDelegate mocks base method.

func (*MockCMDIDOption) SetTrustRootList

func (m *MockCMDIDOption) SetTrustRootList(dids []string) error

SetTrustRootList mocks base method.

func (*MockCMDIDOption) SetVcTemplate

func (m *MockCMDIDOption) SetVcTemplate(id, name, version, vcType, template string) error

SetVcTemplate mocks base method.

func (*MockCMDIDOption) UpdateDidDocument

func (m *MockCMDIDOption) UpdateDidDocument(didDocument string) error

UpdateDidDocument mocks base method.

func (*MockCMDIDOption) VcIssueLog

func (m *MockCMDIDOption) VcIssueLog(issuer, did, templateID, vcID, issueTime string) error

VcIssueLog mocks base method.

type MockCMDIDOptionMockRecorder

type MockCMDIDOptionMockRecorder struct {
	// contains filtered or unexported fields
}

MockCMDIDOptionMockRecorder is the mock recorder for MockCMDIDOption.

func (*MockCMDIDOptionMockRecorder) AddBlackList

func (mr *MockCMDIDOptionMockRecorder) AddBlackList(dids interface{}) *gomock.Call

AddBlackList indicates an expected call of AddBlackList.

func (*MockCMDIDOptionMockRecorder) AddTrustIssuer

func (mr *MockCMDIDOptionMockRecorder) AddTrustIssuer(dids interface{}) *gomock.Call

AddTrustIssuer indicates an expected call of AddTrustIssuer.

func (*MockCMDIDOptionMockRecorder) Delegate

func (mr *MockCMDIDOptionMockRecorder) Delegate(delegateeDid, resource, action, expiration interface{}) *gomock.Call

Delegate indicates an expected call of Delegate.

func (*MockCMDIDOptionMockRecorder) DeleteBlackList

func (mr *MockCMDIDOptionMockRecorder) DeleteBlackList(dids interface{}) *gomock.Call

DeleteBlackList indicates an expected call of DeleteBlackList.

func (*MockCMDIDOptionMockRecorder) DeleteTrustIssuer

func (mr *MockCMDIDOptionMockRecorder) DeleteTrustIssuer(dids interface{}) *gomock.Call

DeleteTrustIssuer indicates an expected call of DeleteTrustIssuer.

func (*MockCMDIDOptionMockRecorder) EmitAddBlackListEvent

func (mr *MockCMDIDOptionMockRecorder) EmitAddBlackListEvent(dids interface{}) *gomock.Call

EmitAddBlackListEvent indicates an expected call of EmitAddBlackListEvent.

func (*MockCMDIDOptionMockRecorder) EmitAddTrustIssuerEvent

func (mr *MockCMDIDOptionMockRecorder) EmitAddTrustIssuerEvent(dids interface{}) *gomock.Call

EmitAddTrustIssuerEvent indicates an expected call of EmitAddTrustIssuerEvent.

func (*MockCMDIDOptionMockRecorder) EmitDelegateEvent

func (mr *MockCMDIDOptionMockRecorder) EmitDelegateEvent(delegatorDid, delegateeDid, resource, action, start, expiration interface{}) *gomock.Call

EmitDelegateEvent indicates an expected call of EmitDelegateEvent.

func (*MockCMDIDOptionMockRecorder) EmitDeleteBlackListEvent

func (mr *MockCMDIDOptionMockRecorder) EmitDeleteBlackListEvent(dids interface{}) *gomock.Call

EmitDeleteBlackListEvent indicates an expected call of EmitDeleteBlackListEvent.

func (*MockCMDIDOptionMockRecorder) EmitDeleteTrustIssuerEvent

func (mr *MockCMDIDOptionMockRecorder) EmitDeleteTrustIssuerEvent(dids interface{}) *gomock.Call

EmitDeleteTrustIssuerEvent indicates an expected call of EmitDeleteTrustIssuerEvent.

func (*MockCMDIDOptionMockRecorder) EmitRevokeDelegateEvent

func (mr *MockCMDIDOptionMockRecorder) EmitRevokeDelegateEvent(delegatorDid, delegateeDid, resource, action interface{}) *gomock.Call

EmitRevokeDelegateEvent indicates an expected call of EmitRevokeDelegateEvent.

func (*MockCMDIDOptionMockRecorder) EmitSetTrustRootListEvent

func (mr *MockCMDIDOptionMockRecorder) EmitSetTrustRootListEvent(dids interface{}) *gomock.Call

EmitSetTrustRootListEvent indicates an expected call of EmitSetTrustRootListEvent.

func (*MockCMDIDOptionMockRecorder) EmitSetVcTemplateEvent

func (mr *MockCMDIDOptionMockRecorder) EmitSetVcTemplateEvent(templateID, templateName, version, vcTemplate interface{}) *gomock.Call

EmitSetVcTemplateEvent indicates an expected call of EmitSetVcTemplateEvent.

func (*MockCMDIDOptionMockRecorder) EmitVcIssueLogEvent

func (mr *MockCMDIDOptionMockRecorder) EmitVcIssueLogEvent(issuer, did, templateID, vcID interface{}) *gomock.Call

EmitVcIssueLogEvent indicates an expected call of EmitVcIssueLogEvent.

func (*MockCMDIDOptionMockRecorder) GetBlackList

func (mr *MockCMDIDOptionMockRecorder) GetBlackList(didSearch, start, count interface{}) *gomock.Call

GetBlackList indicates an expected call of GetBlackList.

func (*MockCMDIDOptionMockRecorder) GetDelegateList

func (mr *MockCMDIDOptionMockRecorder) GetDelegateList(delegatorDid, delegateeDid, resource, action, start, count interface{}) *gomock.Call

GetDelegateList indicates an expected call of GetDelegateList.

func (*MockCMDIDOptionMockRecorder) GetTrustIssuer

func (mr *MockCMDIDOptionMockRecorder) GetTrustIssuer(didSearch, start, count interface{}) *gomock.Call

GetTrustIssuer indicates an expected call of GetTrustIssuer.

func (*MockCMDIDOptionMockRecorder) GetTrustRootList

func (mr *MockCMDIDOptionMockRecorder) GetTrustRootList() *gomock.Call

GetTrustRootList indicates an expected call of GetTrustRootList.

func (*MockCMDIDOptionMockRecorder) GetVcIssueLogs

func (mr *MockCMDIDOptionMockRecorder) GetVcIssueLogs(issuer, did, templateID, start, count interface{}) *gomock.Call

GetVcIssueLogs indicates an expected call of GetVcIssueLogs.

func (*MockCMDIDOptionMockRecorder) GetVcIssuers

func (mr *MockCMDIDOptionMockRecorder) GetVcIssuers(did interface{}) *gomock.Call

GetVcIssuers indicates an expected call of GetVcIssuers.

func (*MockCMDIDOptionMockRecorder) GetVcTemplate

func (mr *MockCMDIDOptionMockRecorder) GetVcTemplate(id, version interface{}) *gomock.Call

GetVcTemplate indicates an expected call of GetVcTemplate.

func (*MockCMDIDOptionMockRecorder) GetVcTemplateList

func (mr *MockCMDIDOptionMockRecorder) GetVcTemplateList(nameSearch, start, count interface{}) *gomock.Call

GetVcTemplateList indicates an expected call of GetVcTemplateList.

func (*MockCMDIDOptionMockRecorder) RevokeDelegate

func (mr *MockCMDIDOptionMockRecorder) RevokeDelegate(delegateeDid, resource, action interface{}) *gomock.Call

RevokeDelegate indicates an expected call of RevokeDelegate.

func (*MockCMDIDOptionMockRecorder) SetTrustRootList

func (mr *MockCMDIDOptionMockRecorder) SetTrustRootList(dids interface{}) *gomock.Call

SetTrustRootList indicates an expected call of SetTrustRootList.

func (*MockCMDIDOptionMockRecorder) SetVcTemplate

func (mr *MockCMDIDOptionMockRecorder) SetVcTemplate(id, name, version, vcType, template interface{}) *gomock.Call

SetVcTemplate indicates an expected call of SetVcTemplate.

func (*MockCMDIDOptionMockRecorder) UpdateDidDocument

func (mr *MockCMDIDOptionMockRecorder) UpdateDidDocument(didDocument interface{}) *gomock.Call

UpdateDidDocument indicates an expected call of UpdateDidDocument.

func (*MockCMDIDOptionMockRecorder) VcIssueLog

func (mr *MockCMDIDOptionMockRecorder) VcIssueLog(issuer, did, templateID, vcID, issueTime interface{}) *gomock.Call

VcIssueLog indicates an expected call of VcIssueLog.

Source Files

  • contract_mock.go

Jump to